=======
History
=======

0.5.3 (2017-11-12)
------------------

* Big updates in documentation about design choices, and better documentation structure
* Updates obsolete HISTORY file

0.5.2 (2017-11-11)
------------------

* Fix MANIFEST typo

0.5.1 (2017-11-10)
------------------

* Add cleanup command for expired notes

0.5.0 (2017-11-09)
------------------

* Add duress key support to allow an immediate deletion in cases of emergency
* Update documentation

0.4.0 (2017-11-09)
------------------

* Allow post request for decrypt mode to have shorter urls in no-store cases
* Update documentation

0.3.0 (2017-10-23)
------------------

* Fixes on the packaged version

0.2.2 (2017-10-23)
------------------

* First release
